==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/ProfileEnrollmentPolicyRuleProfileAttribute.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ProfileEnrollmentPolicyRuleProfileAttribute
 */
@JsonPropertyOrder({ ProfileEnrollmentPolicyRuleProfileAttribute.JSON_PROPERTY_LABEL,
        ProfileEnrollmentPolicyRuleProfileAttribute.JSON_PROPERTY_NAME,
        ProfileEnrollmentPolicyRuleProfileAttribute.JSON_PROPERTY_REQUIRED })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ProfileEnrollmentPolicyRuleProfileAttribute implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_LABEL = "label";
    private String label;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public static final String JSON_PROPERTY_REQUIRED = "required";
    private Boolean required = false;

    public ProfileEnrollmentPolicyRuleProfileAttribute() {
    }

    public ProfileEnrollmentPolicyRuleProfileAttribute label(String label) {

        this.label = label;
        return this;
    }

    /**
     * A display-friendly label for this property
     *
     * @return label
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A display-friendly label for this property")
    @JsonProperty(JSON_PROPERTY_LABEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLabel() {
        return label;
    }

    @JsonProperty(JSON_PROPERTY_LABEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLabel(String label) {
        this.label = label;
    }

    public ProfileEnrollmentPolicyRuleProfileAttribute name(String name) {

        this.name = name;
        return this;
    }

    /**
     * The name of a User Profile property. Can be an existing property.
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The name of a User Profile property. Can be an existing property.")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    public ProfileEnrollmentPolicyRuleProfileAttribute required(Boolean required) {

        this.required = required;
        return this;
    }

    /**
     * (Optional, default &#x60;FALSE&#x60;) Indicates if this property is required for enrollment
     *
     * @return required
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "(Optional, default `FALSE`) Indicates if this property is required for enrollment")
    @JsonProperty(JSON_PROPERTY_REQUIRED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getRequired() {
        return required;
    }

    @JsonProperty(JSON_PROPERTY_REQUIRED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRequired(Boolean required) {
        this.required = required;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ProfileEnrollmentPolicyRuleProfileAttribute profileEnrollmentPolicyRuleProfileAttribute = (ProfileEnrollmentPolicyRuleProfileAttribute) o;
        return Objects.equals(this.label, profileEnrollmentPolicyRuleProfileAttribute.label)
                && Objects.equals(this.name, profileEnrollmentPolicyRuleProfileAttribute.name)
                && Objects.equals(this.required, profileEnrollmentPolicyRuleProfileAttribute.required);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(label, name, required);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ProfileEnrollmentPolicyRuleProfileAttribute {\n");
        sb.append("    label: ").append(toIndentedString(label)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("    required: ").append(toIndentedString(required)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/ProfileEnrollmentPolicyRuleProfileAttribute.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ProfileEnrollmentPolicyRuleProfileAttribute
 */
@JsonPropertyOrder({ ProfileEnrollmentPolicyRuleProfileAttribute.JSON_PROPERTY_LABEL,
        ProfileEnrollmentPolicyRuleProfileAttribute.JSON_PROPERTY_NAME,
        ProfileEnrollmentPolicyRuleProfileAttribute.JSON_PROPERTY_REQUIRED })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ProfileEnrollmentPolicyRuleProfileAttribute implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_LABEL = "label";
    private String label;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public static final String JSON_PROPERTY_REQUIRED = "required";
    private Boolean required = false;

    public ProfileEnrollmentPolicyRuleProfileAttribute() {
    }

    public ProfileEnrollmentPolicyRuleProfileAttribute label(String label) {

        this.label = label;
        return this;
    }

    /**
     * A display-friendly label for this property
     *
     * @return label
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "A display-friendly label for this property")
    @JsonProperty(JSON_PROPERTY_LABEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLabel() {
        return label;
    }

    @JsonProperty(JSON_PROPERTY_LABEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLabel(String label) {
        this.label = label;
    }

    public ProfileEnrollmentPolicyRuleProfileAttribute name(String name) {

        this.name = name;
        return this;
    }

    /**
     * The name of a User Profile property. Can be an existing property.
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The name of a User Profile property. Can be an existing property.")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    public ProfileEnrollmentPolicyRuleProfileAttribute required(Boolean required) {

        this.required = required;
        return this;
    }

    /**
     * (Optional, default &#x60;FALSE&#x60;) Indicates if this property is required for enrollment
     *
     * @return required
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "(Optional, default `FALSE`) Indicates if this property is required for enrollment")
    @JsonProperty(JSON_PROPERTY_REQUIRED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getRequired() {
        return required;
    }

    @JsonProperty(JSON_PROPERTY_REQUIRED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRequired(Boolean required) {
        this.required = required;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ProfileEnrollmentPolicyRuleProfileAttribute profileEnrollmentPolicyRuleProfileAttribute = (ProfileEnrollmentPolicyRuleProfileAttribute) o;
        return Objects.equals(this.label, profileEnrollmentPolicyRuleProfileAttribute.label)
                && Objects.equals(this.name, profileEnrollmentPolicyRuleProfileAttribute.name)
                && Objects.equals(this.required, profileEnrollmentPolicyRuleProfileAttribute.required);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(label, name, required);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ProfileEnrollmentPolicyRuleProfileAttribute {\n");
        sb.append("    label: ").append(toIndentedString(label)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("    required: ").append(toIndentedString(required)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
